==> selenium-maven-plugin-1.0-sources.jar: org/codehaus/mojo/selenium/StopServerMojo.java <==
//
// Generated stub from file:/Users/brett/scm/codehaus/mojo/selenium-maven-plugin/target/checkout/src/main/groovy/org/codehaus/mojo/selenium/StopServerMojo.groovy
//

package org.codehaus.mojo.selenium;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import java.math.BigDecimal;
import java.math.BigInteger;
import org.codehaus.groovy.maven.mojo.GroovyMojo;

/**
 * Stop the Selenium server.
 *
 * @goal stop-server
 * @since 1.0-beta-2
 * @version $Id: StopServerMojo.groovy 6928 2008-05-09 13:12:25Z user57 $
 * @author <a href="mailto:jason@planet57.com">Jason Dillon</a>
 */
public class StopServerMojo
    extends GroovyMojo
{
    /**
     * The port number of the server to connect to.
     *
     * @parameter expression="${port}" default-value="4444"
     */
    private int port = 0;
    public int getPort() {
        throw new InternalError("Stubbed method");
    }
    public void setPort(int value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Skip goal execution
     *
     * @parameter expression="${maven.test.skip}" default-value="false"
     */
    private boolean skip = false;
    public boolean getSkip() {
        throw new InternalError("Stubbed method");
    }
    public boolean isSkip() {
        throw new InternalError("Stubbed method");
    }
    public void setSkip(boolean value) {
        throw new InternalError("Stubbed method");
    }

    public void execute() {
        throw new InternalError("Stubbed method");
    }

    public groovy.lang.MetaClass getMetaClass() {
        throw new InternalError("Stubbed method");
    }

    public void setMetaClass(groovy.lang.MetaClass metaClass) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object invokeMethod(java.lang.String name, java.lang.Object args) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getProperty(java.lang.String name) {
        throw new InternalError("Stubbed method");
    }

    public void setProperty(java.lang.String name, java.lang.Object value) {
        throw new InternalError("Stubbed method");
    }
}

==> selenium-maven-plugin-1.1-sources.jar: org/codehaus/mojo/selenium/StopServerMojo.java <==
//
// Generated stub from file:/home/olamy/dev/sources/mojo/mojo-trunk/selenium-maven-plugin/target/checkout/src/main/groovy/org/codehaus/mojo/selenium/StopServerMojo.groovy
//

package org.codehaus.mojo.selenium;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import java.math.BigDecimal;
import java.math.BigInteger;
import org.codehaus.gmaven.mojo.GroovyMojo;

/**
 * Stop the Selenium server.
 *
 * @goal stop-server
 * @since 1.0-beta-2
 * @version $Id: StopServerMojo.groovy 12859 2010-10-13 09:36:15Z olamy $
 * @author <a href="mailto:jason@planet57.com">Jason Dillon</a>
 */
public class StopServerMojo
    extends GroovyMojo
    implements groovy.lang.GroovyObject
{
    /**
     * The port number of the server to connect to.
     *
     * @parameter expression="${port}" default-value="4444"
     */
    private int port = 0;
    public int getPort() {
        throw new InternalError("Stubbed method");
    }
    public void setPort(int value) {
        throw new InternalError("Stubbed method");
    }

    /**
     * Skip goal execution
     *
     * @parameter expression="${maven.test.skip}" default-value="false"
     */
    private boolean skip = false;
    public boolean getSkip() {
        throw new InternalError("Stubbed method");
    }
    public boolean isSkip() {
        throw new InternalError("Stubbed method");
    }
    public void setSkip(boolean value) {
        throw new InternalError("Stubbed method");
    }

    public void execute() {
        throw new InternalError("Stubbed method");
    }

    public groovy.lang.MetaClass getMetaClass() {
        throw new InternalError("Stubbed method");
    }

    public void setMetaClass(groovy.lang.MetaClass metaClass) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object invokeMethod(java.lang.String name, java.lang.Object args) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getProperty(java.lang.String name) {
        throw new InternalError("Stubbed method");
    }

    public void setProperty(java.lang.String name, java.lang.Object value) {
        throw new InternalError("Stubbed method");
    }
}
